"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var glob = require("glob");
var loader_utils_1 = require("loader-utils");
var loader = function (source) {
    var _this = this;
    this.cacheable && this.cacheable();
    var callback = this.async();
    if (!callback) {
        return this.callback(new Error('style-resources-loader: Asynchronous webpack loader is not supported.'));
    }
    var defaultInjector = function (source, resources) {
        return resources.map(function (_a) {
            var content = _a.content;
            return content;
        }).join('\n') + source;
    };
    var _a = loader_utils_1.getOptions(this) || {}, patterns = _a.patterns, _b = _a.injector, injector = _b === void 0 ? defaultInjector : _b;
    var isString = function (arg) { return typeof arg === 'string'; };
    if (!isString(patterns) && !(Array.isArray(patterns) && patterns.every(isString))) {
        return callback(new Error('style-resources-loader: Expected options.patterns to be a string or an array of string.'
            + (" Instead received " + typeof patterns + ": " + patterns + ".")));
    }
    if (typeof injector !== 'function') {
        return callback(new Error('style-resources-loader: Expected options.injector to be a function.'
            + (" Instead received " + typeof injector + ": " + injector + ".")));
    }
    var _c = this.options.context, context = _c === void 0 ? process.cwd() : _c;
    var files = (isString(patterns) ? [patterns] : patterns)
        .map(function (resource) { return glob.sync(resource).filter(function (file) { return /\.(?:s[ac]|le)ss$/i.test(file); }); })
        .reduce(function (files, partialFiles) { return files.concat(partialFiles); })
        .map(function (file) { return path.resolve(context, file); });
    files.forEach(this.addDependency.bind(this));
    var resources = files.map(function (file) { return ({
        file: file,
        content: fs.readFileSync(file, 'utf8').replace(/@import\s+(?:'([^'])+'|"([^"])"|([^\s"';]))/g, function (match, single, double, unquote) {
            var absolutePath = path.resolve(path.dirname(file), single || double || unquote);
            var relativePath = path.relative(_this.context, absolutePath);
            var quote = (match.match(/['"]$/) || [''])[0];
            return "@import " + quote + relativePath + quote;
        }),
    }); });
    try {
        return callback(null, injector(source, resources));
    }
    catch (err) {
        return callback(err);
    }
};
exports.default = loader;
//# sourceMappingURL=loader.js.map